@@ -26,29 +26,42 @@ class WLANInterface(AbstractInterface):
 
   def pre_init(self):
     self.has_be = get_shell_command_output('ls /lib/modules/$(uname -r) | grep -m 1 wl1251') != ''
-    self.state = {
-    'name': 'WLAN',
-    'dbus': {
-      'on': {'name': self.wifi_module_signal, 'iface': self.wifi_module_iface, 'path': self.wifi_module_path, 'args': {'member_keyword': 'member'}},
-      'connected': {'name': self.wifi_icd2_state_signal, 'iface': self.wifi_icd2_iface, 'path': self.wifi_icd2_path, 'args': {}},
-      'statistics': {'name': self.wifi_icd2_statistics_signal, 'iface': self.wifi_icd2_iface, 'path': self.wifi_icd2_path, 'args': {}}
-    },
-    'images': ('ifsw_statusarea_wlan_off', 'ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_3'),
-    'images_st': ('ifsw_statusarea_wlan_signal_0', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_1', 'ifsw_statusarea_wlan_signal_2', 'ifsw_statusarea_wlan_signal_3', 'ifsw_statusarea_wlan_signal_3'),
-    'text': ('Off', 'On', '<>'),
-    'show': (True, False, False),
-    'banner': (True, True, True),
-    'value': 0,
-    'strength': 0,
-    'modes': ('wlan-stock',),
-    'mode': 0
-    }
+    self.state = {'name': 'WLAN',
+                  'dbus': {'on': {'name': self.wifi_module_signal, 
+                                  'iface': self.wifi_module_iface, 
+                                  'path': self.wifi_module_path, 
+                                  'args': {'member_keyword': 'member'}},
+                           'connected': {'name': self.wifi_icd2_state_signal, 
+                                         'iface': self.wifi_icd2_iface, 
+                                         'path': self.wifi_icd2_path, 
+                                         'args': {}},
+                           'statistics': {'name': self.wifi_icd2_statistics_signal, 
+                                          'iface': self.wifi_icd2_iface, 
+                                          'path': self.wifi_icd2_path, 
+                                          'args': {}}},
+                  'images': ('ifsw_statusarea_wlan_off', 
+                             'ifsw_statusarea_wlan_signal_0', 
+                             'ifsw_statusarea_wlan_signal_3'),
+                  'images_st': ('ifsw_statusarea_wlan_signal_0', 
+                                'ifsw_statusarea_wlan_signal_1', 
+                                'ifsw_statusarea_wlan_signal_1', 
+                                'ifsw_statusarea_wlan_signal_2', 
+                                'ifsw_statusarea_wlan_signal_3', 
+                                'ifsw_statusarea_wlan_signal_3'),
+                  'text': ('Off', 'On', '<>'),
+                  'show': (True, False, False),
+                  'banner': (True, True, True),
+                  'value': 0,
+                  'strength': 0,
+                  'modes': ('wlan-stock',),
+                  'mode': 0}
     if self.has_be:
       self.state['modes'] = ('wlan-stock', 'wlan-bleeding-edge')
-    self.interfaces = {
-      'ICD': [self.wifi_icd2_iface, self.wifi_icd2_path, self.wifi_icd2_iface, '/usr/sbin/icd2', False],
-      'ICD_UI': [self.wifi_icdui_iface, self.wifi_icdui_path, self.wifi_icdui_iface, '/usr/sbin/icd2', False]
-    }
+    self.interfaces = {'ICD': [self.wifi_icd2_iface, self.wifi_icd2_path, 
+                               self.wifi_icd2_iface, '/usr/sbin/icd2', False],
+                       'ICD_UI': [self.wifi_icdui_iface, self.wifi_icdui_path, 
+                                  self.wifi_icdui_iface, '/usr/sbin/icd2', 
+                                  False]}
 
   def process_signal_on(self, *args, **kwargs):
     if args[0] == '/org/freedesktop/Hal/devices/platform_wl12xx':
@@ -78,8 +91,10 @@ class WLANInterface(AbstractInterface):
   def get_status(self):
     result = int(get_shell_command_output('lsmod | grep -m 1 wl12xx') != '')
     if result:
-      try: self.get_interface('ICD').state_req()
-      except: self.reinit_interface('ICD')
+      try:
+        self.get_interface('ICD').state_req()
+      except:
+        self.reinit_interface('ICD')
     return result, 0, 0
 
   def turn_on(self):
@@ -87,14 +102,18 @@ class WLANInterface(AbstractInterface):
       #run_async(self.run_commands, (self.wifi_turn_on_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_on_cmd)
     elif self.state['value'] == 2:
-      try: self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
-      except: self.reinit_interface('ICD')
+      try:
+        self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+      except:
+        self.reinit_interface('ICD')
 
   def turn_off(self):
     if self.state['value'] > 0:
       if self.state['value'] == 2:
-        try: self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
-        except: self.reinit_interface('ICD')
+        try:
+          self.get_interface('ICD').disconnect_req(dbus.UInt32(0x8000))
+        except:
+          self.reinit_interface('ICD')
       #run_async(self.run_commands, (self.wifi_turn_off_cmd,))
       gobject.idle_add(self.run_commands, self.wifi_turn_off_cmd)
 
@@ -104,11 +123,16 @@ class WLANInterface(AbstractInterface):
     self.switched()
 
   def show_connection_dialog(self):
-    self.get_interface('ICD_UI').show_conn_dlg(False)
+    try:
+      self.get_interface('ICD_UI').show_conn_dlg(False)
+    except:
+      self.reinit_interface('ICD_UI')
 
   def scan_request(self):
-    try: self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
-    except: self.reinit_interface('ICD')
+    try:
+      self.get_interface('ICD').scan_req(dbus.UInt32(0), dbus.Array([], signature='s'))
+    except:
+      self.reinit_interface('ICD')
 
   def get_strength(self):
     if self.state['value'] == 2:
